@@ -239,17 +239,16 @@ def getFileMD5(file):
     return hashlib.md5(data).hexdigest()
 
 
-def getFileCRC32(file):
-    data = readBinFile(file)
-    return binascii.crc32(data)
+def getFileCRC(file):
+    return getDataCRCHex(readBinFile(file))
 
 
-def getFileCRCHex(file):
-    return hex(getFileCRC32(file))[2:].zfill(8)
+def getContentCRC(content):
+    return getDataCRCHex(content.decode())
 
 
-def getContentCRCHex(content):
-    return hex(binascii.crc32(content.encode()))[2:].zfill(8)
+def getDataCRC(data):
+    return hex(binascii.crc32(data))[2:].zfill(8)
 
 
 def getClassFullName(classItem):
